@@ -30,6 +30,8 @@ Reference:
 '''
 
 _SEQDB = {
+    '< <BEL>'            : 'BEL / Ctrl-G',
+    '> <BEL>'            : 'BEL / bell',
     '> ESC P<ST>'        : 'DCS / device control string',
     '> ESC ]<ST>'        : 'OSC / operating system command',
     '> ESC ]0<ST>'       : 'OSC 0 / set icon name and window title',
@@ -62,13 +64,15 @@ _SEQDB = {
     '< CSI 0n'           : 'DSR-OS(operating status report) response: "good status"',
     '< CSI 3n'           : 'DSR-OS(operating status report) response: "it has a malfunction"',
     '< CSI ?c'           : 'DA1 Response',
-    '< CSI ?1;2c'        : 'DA1 Response: VT100 with AVO (could be a VT102/rxvt/rxvt-unicode/konsole/kterm/mlterm/iTerm2/tmux/aterm/wterm/Terminal.app(Mac/mrxvt))',
+    '< CSI ?1;2c'        : 'DA1 Response: VT100 with AVO (could be a VT102/rxvt/rxvt-unicode/konsole/kterm/mlterm/iTerm2/tmux/aterm/wterm/Terminal.app(Mac)/mrxvt/MinTTY/TeraTerm/ck)',
     '< CSI ?1;0c'        : 'DA1 Response: VT100 with no options',
     '< CSI ?6c'          : 'DA1 Response: VT102 (could be linux xvt/console/PuTTY/Terminal.app(GNUStep)/yaft)',
     '< CSI ?62c'         : 'DA1 Response: VT200 family (could be mosh)',
     '< CSI ?62;9;c'      : 'DA1 Response: VT200 family (could be gnome-terminal)',
     '< CSI ?64;1;2;6;9;15;21;22c':
     'DA1 Response: VT400 family (could be xterm pl>=280)',
+    '< CSI ?65;1;2;3,4;6;8;9;18;21;22;29;42;44c':
+    'DA1 Response: VT500 family (could be RLogin)',
     '< CSI >c'           : 'DA2 Response',
     '< CSI >0;[*]c'      : 'DA2 Response: VT100',
     '< CSI >0;95;c'      : 'DA2 Response: xterm pattch#95 (could be iTerm/iTerm2)',
@@ -91,12 +95,14 @@ _SEQDB = {
     '< CSI >1;96;0c'     : 'DA2 Response: VT220 (could be xterm pattch#96, mlterm)',
     '< CSI >1;2403;0c'   : 'DA2 Response: VT220 (could be VTE, such as gnome-terminal)',
     '< CSI >1;2802;0c'   : 'DA2 Response: VT220 (could be VTE, such as gnome-terminal)',
-    '< CSI >2;[*]c'      : 'DA2 Response: VT240',
-    '< CSI >18;[*]c'     : 'DA2 Response: VT330',
-    '< CSI >19;[*]c'     : 'DA2 Response: VT340',
-    '< CSI >19;[*]c'     : 'DA2 Response: VT340',
-    '< CSI >24;[*]c'     : 'DA2 Response: VT320',
-    '< CSI >41;[*]c'     : 'DA2 Response: VT420',
+    '< CSI >2;[2]c'      : 'DA2 Response: VT240',
+    '< CSI >18;[2]c'     : 'DA2 Response: VT330',
+    '< CSI >19;[2]c'     : 'DA2 Response: VT340',
+    '< CSI >19;[2]c'     : 'DA2 Response: VT340',
+    '< CSI >24;[2]c'     : 'DA2 Response: VT320',
+    '< CSI >32;[2]c'     : 'DA2 Response: VT382',
+    '< CSI >32;100;2c'   : 'DA2 Response: VT382 (could be TeraTerm)',
+    '< CSI >41;[2]c'     : 'DA2 Response: VT420',
     '< CSI >41;280;0c'   : 'DA2 Response: VT420 (could be xterm patch#280)',
     '< CSI >41;281;0c'   : 'DA2 Response: VT420 (could be xterm patch#281)',
     '< CSI >41;282;0c'   : 'DA2 Response: VT420 (could be xterm patch#282)',
@@ -110,10 +116,14 @@ _SEQDB = {
     '< CSI >41;290;0c'   : 'DA2 Response: VT420 (could be xterm patch#290)',
     '< CSI >41;291;0c'   : 'DA2 Response: VT420 (could be xterm patch#291)',
     '< CSI >41;292;0c'   : 'DA2 Response: VT420 (could be xterm patch#292)',
-    '< CSI >61;[*]c'     : 'DA2 Response: VT510',
-    '< CSI >64;[*]c'     : 'DA2 Response: VT520',
-    '< CSI >65;[*]c'     : 'DA2 Response: VT525',
+    '< CSI >61;[2]c'     : 'DA2 Response: VT510',
+    '< CSI >64;[2]c'     : 'DA2 Response: VT520',
+    '< CSI >65;[2]c'     : 'DA2 Response: VT525',
+    '< CSI >65;100;1c'   : 'DA1 Response: VT500 family (could be RLogin)',
+    '< CSI >77;[2]c'     : 'DA2 Response: could be MinTTY',
+    '< CSI >77;10003;c'  : 'DA2 Response: could be MinTTY 1.0.3',
     '< CSI >82;[*]c'     : 'DA2 Response: could be mrxvt',
+    '< CSI >82;20710;0c' : 'DA2 Response: could be rxvt/ck',
     '< CSI >82;0.5.4;0c' : 'DA2 Response: could be mrxvt 0.5.4',
     '< CSI >83;[*]c'     : 'DA2 Response: could be GNU Screen',
     '< CSI >83;40000;0c' : 'DA2 Response: could be GNU Screen 4.0.0',
